<?php

namespace App\Http\Controllers\Dashboard;

use App\DataTables\MonitoringQuestionsDataTable;
use App\Exports\MonitoringQuestionsExport;
use App\Http\Controllers\Controller;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use App\Models\MonitoringQuestion;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rule;
use Maatwebsite\Excel\Facades\Excel;

class MonitoringQuestionsController extends Controller
{
    //
    //
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(MonitoringQuestionsDataTable $dataTable){
        return $dataTable->render('dashboard.monitoring_questions.index');
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //

        return view('dashboard.monitoring_questions.create_edit');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validateMonitoringQuestions($request);
        MonitoringQuestion::create(array_merge($request->only(['name','type','status']),['created_by'=>auth()->id()]));
        alert()->success(__('Success'),__('Create Successfully'));
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
        return abort(404);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(MonitoringQuestion $monitoring_question)
    {
        //
        return view('dashboard.monitoring_questions.create_edit',compact('monitoring_question'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, MonitoringQuestion $monitoring_question)
    {
        //
        $this->validateMonitoringQuestions($request);
        $updateData=array_merge($request->only('name','type','status'),['updated_by'=>auth()->id()]);
        $monitoring_question->update($updateData);
        alert()->success(__('Success'),__('Update Successfully'));
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(MonitoringQuestion $monitoring_question)
    {
        //
        $monitoring_question->deleted_by=auth()->id();
        $monitoring_question->save();
        $monitoring_question->delete();
        return response()->json(['success'=>true,'message'=>__('Delete Successful')]);
    }

    public function validateMonitoringQuestions($request){
        $valid=[

            'status'=>'required|in:'.implode(',',config('app.statusArray')),
        ];
        if($request->monitoring_question){
//            $valid['email']='required|email|unique:monitoring_questions,email,'.$request->monitoring_question->id.',NULL,deleted_at,NULL';
            $valid['name']=['required',Rule::unique('monitoring_questions','name')->whereNull('deleted_at')->ignore($request->monitoring_question->id,'id')];
        }else{
            $valid['name']=['required',Rule::unique('monitoring_questions','name')->whereNull('deleted_at')];
        }
        return $request->validate($valid);
    }
    public function deleteMulti(Request $request){
        $count=MonitoringQuestion::whereIn('id',$request->IDS)->update(['deleted_by'=>auth()->id(),'deleted_at'=>now()]);
        return response()->json(['success'=>true,'message'=>__('Delete :count Successful',['count'=>$count])]);
    }
    public function export(Request $request){
        switch ($request->export_question){
            case'csv':
                return Excel::download(new MonitoringQuestionsExport,'monitoring_questions_'.time().'.csv',\Maatwebsite\Excel\Excel::CSV);
                break;
            case'excel':
                return Excel::download(new MonitoringQuestionsExport,'monitoring_questions_'.time().'.xlsx',\Maatwebsite\Excel\Excel::XLSX);
                break;
            case'pdf':
                $monitoring_questions=MonitoringQuestion::query();
                if(request('IDS')){
                    $monitoring_questions=$monitoring_questions->whereIn('id',explode(',',request('IDS')));
                }
                $monitoring_questions=$monitoring_questions->get();
                return Pdf::loadView('dashboard.monitoring_questions.export_pdf',['monitoring_questions'=>$monitoring_questions])->download('monitoring_questions_'.time().'.pdf');
                break;
        }

    }

}
