<?php

namespace App\Http\Controllers\Dashboard;

use App\DataTables\MonitoringTypesDataTable;
use App\Exports\MonitoringTypesExport;
use App\Http\Controllers\Controller;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use App\Models\MonitoringType;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rule;
use Maatwebsite\Excel\Facades\Excel;

class MonitoringTypesController extends Controller
{
    //
    //
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(MonitoringTypesDataTable $dataTable){
        return $dataTable->render('dashboard.monitoring_types.index');
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //

        return view('dashboard.monitoring_types.create_edit');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validateMonitoringTypes($request);
        MonitoringType::create(array_merge($request->only(['name','status']),['created_by'=>auth()->id()]));
        alert()->success(__('Success'),__('Create Successfully'));
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
        return abort(404);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(MonitoringType $monitoring_type)
    {
        //
        return view('dashboard.monitoring_types.create_edit',compact('monitoring_type'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, MonitoringType $monitoring_type)
    {
        //
        $this->validateMonitoringTypes($request);
        $updateData=array_merge($request->only('name','status'),['updated_by'=>auth()->id()]);
        $monitoring_type->update($updateData);
        alert()->success(__('Success'),__('Update Successfully'));
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(MonitoringType $monitoring_type)
    {
        //
        $monitoring_type->deleted_by=auth()->id();
        $monitoring_type->save();
        $monitoring_type->delete();
        return response()->json(['success'=>true,'message'=>__('Delete Successful')]);
    }

    public function validateMonitoringTypes($request){
        $valid=[

            'status'=>'required|in:'.implode(',',config('app.statusArray')),
        ];
        if($request->monitoring_type){
//            $valid['email']='required|email|unique:monitoring_types,email,'.$request->monitoring_type->id.',NULL,deleted_at,NULL';
            $valid['name']=['required',Rule::unique('monitoring_types','name')->whereNull('deleted_at')->ignore($request->monitoring_type->id,'id')];
        }else{
            $valid['name']=['required',Rule::unique('monitoring_types','name')->whereNull('deleted_at')];
        }
        return $request->validate($valid);
    }
    public function deleteMulti(Request $request){
        $count=MonitoringType::whereIn('id',$request->IDS)->update(['deleted_by'=>auth()->id(),'deleted_at'=>now()]);
        return response()->json(['success'=>true,'message'=>__('Delete :count Successful',['count'=>$count])]);
    }
    public function export(Request $request){
        switch ($request->export_type){
            case'csv':
                return Excel::download(new MonitoringTypesExport,'monitoring_types_'.time().'.csv',\Maatwebsite\Excel\Excel::CSV);
                break;
            case'excel':
                return Excel::download(new MonitoringTypesExport,'monitoring_types_'.time().'.xlsx',\Maatwebsite\Excel\Excel::XLSX);
                break;
            case'pdf':
                $monitoring_types=MonitoringType::query();
                if(request('IDS')){
                    $monitoring_types=$monitoring_types->whereIn('id',explode(',',request('IDS')));
                }
                $monitoring_types=$monitoring_types->get();
                return Pdf::loadView('dashboard.monitoring_types.export_pdf',['monitoring_types'=>$monitoring_types])->download('monitoring_types_'.time().'.pdf');
                break;
        }

    }

}
