<?php

namespace App\Http\Controllers\Dashboard;

use App\DataTables\MonitoringsDataTable;
use App\Exports\MonitoringsExport;
use App\Http\Controllers\Controller;
use App\Models\MonitoringQuestion;
use App\Models\MonitoringQuestionCounter;
use App\Models\MonitoringType;
use App\Models\User;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use App\Models\Monitoring;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rule;
use Maatwebsite\Excel\Facades\Excel;

class MonitoringsController extends Controller
{
    //
    //
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(MonitoringsDataTable $dataTable){
        return $dataTable->render('dashboard.monitorings.index');
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $usersSelectorArray=User::get();
        $tableRows=DB::select("SELECT MAX(count) AS max FROM (SELECT COUNT('X') AS count FROM `monitoring_questions` WHERE status='published' GROUP BY type) AS dd")[0]->max;
        $tableEndUserCritical=MonitoringQuestion::where('type','end_user_critical')->get()->toArray();
        $tableBusinessCritical=MonitoringQuestion::where('type','business_critical')->get()->toArray();
        $tableNoneCritical=MonitoringQuestion::where('type','non_critical')->get()->toArray();
        return view('dashboard.monitorings.create_edit',compact('usersSelectorArray','tableRows','tableBusinessCritical','tableEndUserCritical','tableNoneCritical'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validateMonitorings($request);
//        dd($request->input());
        $monitoring=Monitoring::create(array_merge($request->only(['extinction','agent_id','team_leader_id','supervisor_id','project_id','customer_number','call_at','monitored_at','monitored_type_id','comment']),['end_user_critical'=>$request->end_user_critical??0,'business_critical'=>$request->business_critical??0,'non_critical'=>$request->non_critical??0,'call_status'=>$request->call_status??'failed','created_by'=>auth()->id()]));
        foreach ($request->question as $id=>$value){
            MonitoringQuestionCounter::create([
                'monitoring_id'=>$monitoring->id,
                'question_id'=>$id,
                'counter'=>$value?$value:0,
                'created_by'=>auth()->id(),
            ]);
        }
        alert()->success(__('Success'),__('Create Successfully'));
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
        return abort(404);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Monitoring $monitoring)
    {
        //
        $usersSelectorArray=User::get();
        $tableRows=DB::select("SELECT MAX(count) AS max FROM (SELECT COUNT('X') AS count FROM `monitoring_questions` WHERE status='published' GROUP BY type) AS dd")[0]->max;
        $tableEndUserCritical=MonitoringQuestion::where('type','end_user_critical')->get()->toArray();
        $tableBusinessCritical=MonitoringQuestion::where('type','business_critical')->get()->toArray();
        $tableNoneCritical=MonitoringQuestion::where('type','non_critical')->get()->toArray();
        return view('dashboard.monitorings.create_edit',compact('monitoring','usersSelectorArray','tableRows','tableEndUserCritical','tableBusinessCritical','tableNoneCritical'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Monitoring $monitoring)
    {
        //
        $this->validateMonitorings($request);
        $updateData=array_merge($request->only('extinction','agent_id','team_leader_id','supervisor_id','project_id','customer_number','call_at','monitored_at','monitored_type_id','comment'),['end_user_critical'=>$request->end_user_critical??0,'business_critical'=>$request->business_critical??0,'non_critical'=>$request->non_critical??0,'call_status'=>$request->call_status??'failed','updated_by'=>auth()->id()]);
        $monitoring->update($updateData);
        foreach ($request->question as $id=>$value){
            $counter=MonitoringQuestionCounter::where('monitoring_id',$monitoring->id)->where('question_id',$id)->first();
            if($counter){
                $counter->update(['counter'=>$value?$value:0,'updated_by'=>auth()->id()]);
            }else{
                MonitoringQuestionCounter::create([
                    'monitoring_id'=>$monitoring->id,
                    'question_id'=>$id,
                    'counter'=>$value?$value:0,
                    'created_by'=>auth()->id(),
                ]);
            }
        }
        alert()->success(__('Success'),__('Update Successfully'));
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Monitoring $monitoring)
    {
        //
        $monitoring->deleted_by=auth()->id();
        $monitoring->save();
        $monitoring->delete();
        return response()->json(['success'=>true,'message'=>__('Delete Successful')]);
    }

    public function validateMonitorings($request){
        $valid=[
            'extinction'=>'required',
            'agent_id'=>'required',
            'team_leader_id'=>'required',
            'supervisor_id'=>'required',
            'project_id'=>'required',
            'customer_number'=>'required',
            'call_at'=>'required',
            'monitored_at'=>'required',
            'monitored_type_id'=>'required',
        ];
//        if($request->monitoring){
////            $valid['email']='required|email|unique:monitorings,email,'.$request->monitoring->id.',NULL,deleted_at,NULL';
//            $valid['name']=['required',Rule::unique('monitorings','name')->whereNull('deleted_at')->ignore($request->monitoring->id,'id')];
//        }else{
//            $valid['name']=['required',Rule::unique('monitorings','name')->whereNull('deleted_at')];
//        }
        return $request->validate($valid);
    }
    public function deleteMulti(Request $request){
        $count=Monitoring::whereIn('id',$request->IDS)->update(['deleted_by'=>auth()->id(),'deleted_at'=>now()]);
        return response()->json(['success'=>true,'message'=>__('Delete :count Successful',['count'=>$count])]);
    }
    public function export(Request $request){
        switch ($request->export_type){
            case'csv':
                return Excel::download(new MonitoringsExport,'monitorings_'.time().'.csv',\Maatwebsite\Excel\Excel::CSV);
                break;
            case'excel':
                return Excel::download(new MonitoringsExport,'monitorings_'.time().'.xlsx',\Maatwebsite\Excel\Excel::XLSX);
                break;
            case'pdf':
                $monitorings=Monitoring::query();
                if(request('IDS')){
                    $monitorings=$monitorings->whereIn('id',explode(',',request('IDS')));
                }
                $monitorings=$monitorings->get();
                return Pdf::loadView('dashboard.monitorings.export_pdf',['monitorings'=>$monitorings])->download('monitorings_'.time().'.pdf');
                break;
        }

    }

}
